package com.autocareai.mvvmdemo.common.tool

import com.autocareai.lib.net.HttpConfig
import com.autocareai.lib.net.HttpUtil
import com.autocareai.mvvmdemo.common.api.CommonApi
import okhttp3.logging.HttpLoggingInterceptor

/**
 * <pre>
 *     author : Taylor Zhang
 *     time   : 2020/06/24
 *     desc   : 网络请求工具类
 *     version: 1.0.0
 * </pre>
 */
object HttpTool {

    // 网络请求连接超时时间
    private const val DEFAULT_CONNECT_TIMEOUT = 5000L

    // 网络请求其他超时时间
    private const val OTHER_TIME_OUT = 30000L

    /**
     * 初始化网络请求框架
     */
    fun init() {
        val httpConfig = HttpConfig.Builder()
            .baseUrl(CommonApi.API_URL)
            // 设置全局超时时间
            .connectTimeoutMillis(DEFAULT_CONNECT_TIMEOUT)
            .readTimeoutMillis(OTHER_TIME_OUT)
            .writeTimeoutMillis(OTHER_TIME_OUT)
            .setLogLevel(HttpLoggingInterceptor.Level.BODY)
            .build()
        HttpUtil.initHttpConfig(httpConfig)

        // 初始化全局错误监听
        initGlobalErrorListener()
    }

    private fun initGlobalErrorListener() {
        HttpUtil.setGlobalErrorListener { observable, code, message ->
            // 处理全局错误
            return@setGlobalErrorListener false
        }
    }
}